Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3)

Unified Diff: third_party/libaddressinput/chromium/string_compare.cc

Issue 1911823002: Convert //third_party from scoped_ptr to std::unique_ptr (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Update crashpad's README.chromium Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/libaddressinput/chromium/string_compare.cc
diff --git a/third_party/libaddressinput/chromium/string_compare.cc b/third_party/libaddressinput/chromium/string_compare.cc
index 8996cd8fadde73132f642db607da7e8358eb9c82..460575656c4fae09a41150caaebb7ab7b221058e 100644
--- a/third_party/libaddressinput/chromium/string_compare.cc
+++ b/third_party/libaddressinput/chromium/string_compare.cc
@@ -4,10 +4,11 @@
#include "third_party/libaddressinput/src/cpp/src/util/string_compare.h"
+#include <memory>
+
#include "base/lazy_instance.h"
#include "base/logging.h"
#include "base/macros.h"
-#include "base/memory/scoped_ptr.h"
#include "third_party/icu/source/i18n/unicode/coll.h"
namespace i18n {
@@ -35,10 +36,7 @@ class IcuStringComparer {
}
private:
- // ::scoped_ptr is from "base/memory/scoped_ptr.h", which does not interfere
- // with ::i18n::addressinput::scoped_ptr from
- // <libaddressinput/util/scoped_ptr.h>.
- ::scoped_ptr<icu::Collator> collator_;
+ std::unique_ptr<icu::Collator> collator_;
DISALLOW_COPY_AND_ASSIGN(IcuStringComparer);
};
@@ -48,7 +46,7 @@ static base::LazyInstance<IcuStringComparer> g_comparer =
} // namespace
// Dummy required for scoped_ptr<Impl>.
class StringCompare::Impl {};
StringCompare::StringCompare() {}
@@ -48,7 +46,7 @@ static base::LazyInstance<IcuStringComparer> g_comparer =
} // namespace
-// Dummy required for scoped_ptr<Impl>.
+// Dummy required for std::unique_ptr<Impl>.
class StringCompare::Impl {};
StringCompare::StringCompare() {}

Powered by Google App Engine
This is Rietveld 408576698